@@ -29,6 +29,10 @@ def read_file(filename, isbin=False, encoding="utf-8"):
     with open(filename, mode=mode, encoding=encoding) as f:
         return f.read()
 
+def read_lines(filename, encoding="utf-8"):
+    "read lines from file"
+    with open(filename, mode="r", encoding=encoding) as f:
+        return f.readlines()
 
 def copy_file(src, dst):
     makedirs(dst, True)
